@@ -16,7 +16,7 @@ This CDK library is a WIP and not ready for production use.
 
 **Testing**
 
-* Create a test project that utilizes this library
+* Create a test project that utilizes this library (you can use a development version by utilizing `yarn link`, but note you might need to set a static dependency for CDK versions or `constructs` in the local app or you'll get errors about mismatched object types)
 * Create a test stack
 * Synthesize the test stack with `cdk synth --no-staging > template.yml`
 * Get the handler function names from the template
@@ -24,7 +24,7 @@ This CDK library is a WIP and not ready for production use.
 * Run the `handler_tests` python files with `pytest` like follows:
 
 ```
-TEST_ACCOUNT_NAME='<name>' TEST_ACCOUNT_EMAIL='<email>' TEST_ACCOUNT_ORIGINAL_OU='<original ou id>' ACCOUNT_LAMBDA_FUNCTION_NAME='<name you noted earlier>' OU_LAMBDA_FUNCTION_NAME='<name you noted earlier>' pytest ./handler_tests/<handler>/test.py -rA --capture=sys
+TEST_ACCOUNT_NAME='<name>' TEST_ACCOUNT_EMAIL='<email>' TEST_ACCOUNT_ORIGINAL_OU='<original ou id>' ACCOUNT_LAMBDA_FUNCTION_NAME='<name you noted earlier>' OU_LAMBDA_FUNCTION_NAME='<name you noted earlier>' pytest ./handler_tests/<test file name>.py -rA --capture=sys
 ```
 
 * Using the name, email, and original OU env variables here allows the test suite to re-use a single test account. Given deleting accounts is not simple you likely dont want to randomly create a new account every time you run tests.
@@ -32,7 +32,7 @@ TEST_ACCOUNT_NAME='<name>' TEST_ACCOUNT_EMAIL='<email>' TEST_ACCOUNT_ORIGINAL_OU
 * You can run the provided tests against the real lambda function by getting the deployed function name from AWS and setting the `RUN_LOCALLY` env variable
 
 ```
-TEST_ACCOUNT_NAME='<name>' TEST_ACCOUNT_EMAIL='<email>' TEST_ACCOUNT_ORIGINAL_OU='<original ou id>' RUN_LOCALLY='false' ACCOUNT_LAMBDA_FUNCTION_NAME='<name you noted earlier>' OU_LAMBDA_FUNCTION_NAME='<name from AWS>' pytest ./handler_tests/<handler>/test.py -rA --capture=sys
+TEST_ACCOUNT_NAME='<name>' TEST_ACCOUNT_EMAIL='<email>' TEST_ACCOUNT_ORIGINAL_OU='<original ou id>' RUN_LOCALLY='false' ACCOUNT_LAMBDA_FUNCTION_NAME='<name you noted earlier>' OU_LAMBDA_FUNCTION_NAME='<name from AWS>' pytest ./handler_tests/<test file name>.py -rA --capture=sys
 ```
 
 ## Why can't I move an OU?
@@ -318,6 +318,133 @@ class AccountResourceProps(AccountProps):
         )
 
 
+@jsii.interface(
+    jsii_type="@renovosolutions/cdk-library-aws-organization.IPAMAdministratorProps"
+)
+class IPAMAdministratorProps(typing_extensions.Protocol):
+    '''The properties of an OrganizationAccount custom resource.'''
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="delegatedAdminAccountId")
+    def delegated_admin_account_id(self) -> builtins.str:
+        '''The account id of the IPAM administrator.'''
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="provider")
+    def provider(self) -> aws_cdk.custom_resources.Provider:
+        '''The provider to use for the custom resource that will handle IPAM admin delegation.
+
+        You can create a provider with the IPAMAdministratorProvider class
+        '''
+        ...
+
+
+class _IPAMAdministratorPropsProxy:
+    '''The properties of an OrganizationAccount custom resource.'''
+
+    __jsii_type__: typing.ClassVar[str] = "@renovosolutions/cdk-library-aws-organization.IPAMAdministratorProps"
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="delegatedAdminAccountId")
+    def delegated_admin_account_id(self) -> builtins.str:
+        '''The account id of the IPAM administrator.'''
+        return typing.cast(builtins.str, jsii.get(self, "delegatedAdminAccountId"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="provider")
+    def provider(self) -> aws_cdk.custom_resources.Provider:
+        '''The provider to use for the custom resource that will handle IPAM admin delegation.
+
+        You can create a provider with the IPAMAdministratorProvider class
+        '''
+        return typing.cast(aws_cdk.custom_resources.Provider, jsii.get(self, "provider"))
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IPAMAdministratorProps).__jsii_proxy_class__ = lambda : _IPAMAdministratorPropsProxy
+
+
+class IPAMAdministratorProvider(
+    constructs.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@renovosolutions/cdk-library-aws-organization.IPAMAdministratorProvider",
+):
+    def __init__(
+        self,
+        scope: constructs.Construct,
+        id: builtins.str,
+        props: "IPAMAdministratorProviderProps",
+    ) -> None:
+        '''
+        :param scope: -
+        :param id: -
+        :param props: -
+        '''
+        jsii.create(self.__class__, self, [scope, id, props])
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="provider")
+    def provider(self) -> aws_cdk.custom_resources.Provider:
+        return typing.cast(aws_cdk.custom_resources.Provider, jsii.get(self, "provider"))
+
+
+@jsii.interface(
+    jsii_type="@renovosolutions/cdk-library-aws-organization.IPAMAdministratorProviderProps"
+)
+class IPAMAdministratorProviderProps(typing_extensions.Protocol):
+    '''The properties of an IPAM administrator custom resource provider.'''
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="role")
+    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+        '''The role the custom resource should use for working with the IPAM administrator delegation if one is not provided one will be created automatically.'''
+        ...
+
+
+class _IPAMAdministratorProviderPropsProxy:
+    '''The properties of an IPAM administrator custom resource provider.'''
+
+    __jsii_type__: typing.ClassVar[str] = "@renovosolutions/cdk-library-aws-organization.IPAMAdministratorProviderProps"
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="role")
+    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+        '''The role the custom resource should use for working with the IPAM administrator delegation if one is not provided one will be created automatically.'''
+        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], jsii.get(self, "role"))
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IPAMAdministratorProviderProps).__jsii_proxy_class__ = lambda : _IPAMAdministratorProviderPropsProxy
+
+
+class IPAMdministrator(
+    constructs.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@renovosolutions/cdk-library-aws-organization.IPAMdministrator",
+):
+    '''The construct to create or update the delegated IPAM administrator for an organization.
+
+    This relies on the custom resource provider IPAMAdministratorProvider.
+    '''
+
+    def __init__(
+        self,
+        scope: constructs.Construct,
+        id: builtins.str,
+        props: IPAMAdministratorProps,
+    ) -> None:
+        '''
+        :param scope: -
+        :param id: -
+        :param props: -
+        '''
+        jsii.create(self.__class__, self, [scope, id, props])
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resource")
+    def resource(self) -> aws_cdk.CustomResource:
+        return typing.cast(aws_cdk.CustomResource, jsii.get(self, "resource"))
+
+
 @jsii.data_type(
     jsii_type="@renovosolutions/cdk-library-aws-organization.OUObject",
     jsii_struct_bases=[],
@@ -809,6 +936,10 @@ class OrganizationOUProviderProps:
 __all__ = [
     "AccountProps",
     "AccountResourceProps",
+    "IPAMAdministratorProps",
+    "IPAMAdministratorProvider",
+    "IPAMAdministratorProviderProps",
+    "IPAMdministrator",
     "OUObject",
     "OUProps",
     "OUResourceProps",
